;;;; banner.scm


(define-constant +banner+ #<<EOF
CHICKEN
(c) 2008-2019, The CHICKEN Team
(c) 2000-2007, Felix L. Winkelmann

EOF
)
